# Important note!
# There are at least two quite separate OCaml cairo projects.
#
# This is (packaged in Mageia >= 7):
#   http://forge.ocamlcore.org/projects/cairo/
#   https://github.com/Chris00/ocaml-cairo
#
# The other one (which used to be packaged in Mageia <= 6) is:
#   http://cairographics.org/cairo-ocaml/

%define rel 1
# "fix" underlinking:
%define _disable_ld_no_undefined 1


Name:           ocaml-cairo
Epoch:          2
Version:        0.6.4
Release:        %mkrel %{rel}

Summary:        OCaml library for accessing cairo graphics
Group:          Development/OCaml

License:        LGPLv3+
URL:            https://github.com/Chris00/%{name}

Source0:        %{url}/releases/download/%{version}/cairo2-%{version}.tbz

BuildRequires:  ocaml >= 4.02
BuildRequires:  ocaml-dune
BuildRequires:  ocaml-dune-configurator-devel
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-lablgtk2-devel
BuildRequires:  pkgconfig(cairo) >= 1.2.0
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gtk+-2.0)

%global _description %{expand:
Cairo is a multi-platform library providing anti-aliased vector-based
rendering for multiple target backends. Paths consist of line segments
and cubic splines and can be rendered at any width with various join
and cap styles. All colors may be specified with optional translucence
(opacity/alpha) and combined using the extended Porter/Duff
compositing algebra as found in the X Render Extension.

Cairo exports a stateful rendering API similar in spirit to the path
construction, text, and painting operators of PostScript, (with the
significant addition of translucence in the imaging model). When
complete, the API is intended to support the complete imaging model of
PDF 1.4.}

%description
%_description

This package contains OCaml bindings for Cairo.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       %{name}%{?_isa} = %{epoch}:%{version}-%{release}
Requires:       ocaml-lablgtk2-devel%{?_isa}
Requires:       cairo-devel

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.


%package        gtk
Summary:        OCaml library to render cairo on a gtk2 canvas
Requires:       %{name}%{?_isa} = %{epoch}:%{version}-%{release}


%description    gtk
%_description

This package contains OCaml bindings for rendering cairo on a gtk2 canvas.


%package        gtk-devel
Summary:        Development files for %{name}-gtk
Requires:       %{name}-gtk%{?_isa} = %{epoch}:%{version}-%{release}
Requires:       %{name}-devel%{?_isa} = %{epoch}:%{version}-%{release}


%description    gtk-devel
The %{name}-gtk-devel package contains libraries and signature files for
developing applications that use %{name}-gtk.


%package        pango
Summary:        OCaml library to use pango with cairo
Requires:       %{name}%{?_isa} = %{epoch}:%{version}-%{release}


%description    pango
%_description

This package contains OCaml bindings to use pango with cairo.


%package        pango-devel
Summary:        Development files for %{name}-pango
Requires:       %{name}-pango%{?_isa} = %{epoch}:%{version}-%{release}
Requires:       %{name}-devel%{?_isa} = %{epoch}:%{version}-%{release}


%description    pango-devel
The %{name}-pango-devel package contains libraries and signature files
for developing applications that use %{name}-pango.


%prep
%autosetup -n cairo2-%{version} -p1


%build
cairo_cflags="$(pkgconf --cflags cairo)"
cairo_libs="$(pkgconf --libs cairo)"
gtk_cflags="$(pkgconf --cflags gtk+-2.0)"
gtk_libs="$(pkgconf --libs gtk+-2.0)"
export CAIRO_CFLAGS="%{optflags} $cairo_cflags"
export CAIRO_LIBS="$RPM_LD_FLAGS $cairo_libs"
export GTK_CFLAGS="%{optflags} $gtk_cflags"
export GTK_LIBS="$RPM_LD_FLAGS $gtk_libs"
dune build

# Dune passes RPM_LD_FLAGS to ocamlmklib without -ldopt, resulting in "Unknown
# option" warnings from ocamlmklib and a library that has not been linked with
# the correct flags.  We can't add -ldopt ourselves, since that breaks
# compilation of the cmxs files.  This seems to be a weakness of dune; linker
# flags and libraries to be linked with have to be specified together, and
# nothing takes care of separating them and adding ldopt as necessary.  We
# relink manually to address the problem.
pushd _build/default/src
ocamlmklib -g -ldopt "$RPM_LD_FLAGS" $cairo_libs -o cairo_stubs cairo_stubs.o
cd ../gtk
ocamlmklib -g -ldopt "$RPM_LD_FLAGS" $gtk_libs -o cairo_gtk_stubs cairo_gtk_stubs.o
cd ../pango
ocamlmklib -g -ldopt "$RPM_LD_FLAGS" $gtk_libs -o cairo_pango_stubs cairo_pango_stubs.o
popd


%install
dune install --destdir=%{buildroot}

# This just contains the README, LICENSE, and CHANGES files, 3 times, in
# directories with names other than the ones we want.
rm -rf %{buildroot}%{_prefix}/doc

%ifarch %{ocaml_native_compiler}
# Add missing executable bits
chmod a+x %{buildroot}%{_libdir}/ocaml/*/*.cmxs
%endif

# Remove files we do not need to package
rm %{buildroot}%{_libdir}/ocaml/*/*.ml


%check
#dune runtest

%files
%doc CHANGES.md README.md
%license GPL3.md LICENSE.md
%dir %{_libdir}/ocaml/cairo2
%{_libdir}/ocaml/cairo2/META
%{_libdir}/ocaml/cairo2/cairo.cma
%{_libdir}/ocaml/cairo2/cairo.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/cairo2/cairo.cmxs
%endif
%{_libdir}/ocaml/stublibs/dllcairo_stubs.so

%files devel
# XXX The tutorial doesn't build.
%doc examples
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/cairo2/cairo.a
%{_libdir}/ocaml/cairo2/cairo.cmx
%{_libdir}/ocaml/cairo2/cairo.cmxa
%endif
%{_libdir}/ocaml/cairo2/cairo.cmt
%{_libdir}/ocaml/cairo2/cairo.cmti
%{_libdir}/ocaml/cairo2/cairo.mli
%{_libdir}/ocaml/cairo2/cairo_ocaml.h
%{_libdir}/ocaml/cairo2/dune-package
%{_libdir}/ocaml/cairo2/libcairo_stubs.a
%{_libdir}/ocaml/cairo2/opam


%files gtk
%dir %{_libdir}/ocaml/cairo2-gtk
%{_libdir}/ocaml/cairo2-gtk/META
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.cma
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.cmxs
%endif
%{_libdir}/ocaml/stublibs/dllcairo_gtk_stubs.so


%files gtk-devel
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.a
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.cmx
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.cmxa
%endif
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.cmt
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.cmti
%{_libdir}/ocaml/cairo2-gtk/cairo_gtk.mli
%{_libdir}/ocaml/cairo2-gtk/dune-package
%{_libdir}/ocaml/cairo2-gtk/libcairo_gtk_stubs.a
%{_libdir}/ocaml/cairo2-gtk/opam


%files pango
%dir %{_libdir}/ocaml/cairo2-pango
%{_libdir}/ocaml/cairo2-pango/META
%{_libdir}/ocaml/cairo2-pango/cairo_pango.cma
%{_libdir}/ocaml/cairo2-pango/cairo_pango.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/cairo2-pango/cairo_pango.cmxs
%endif
%{_libdir}/ocaml/stublibs/dllcairo_pango_stubs.so


%files pango-devel
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/cairo2-pango/cairo_pango.a
%{_libdir}/ocaml/cairo2-pango/cairo_pango.cmx
%{_libdir}/ocaml/cairo2-pango/cairo_pango.cmxa
%endif
%{_libdir}/ocaml/cairo2-pango/cairo_pango.cmt
%{_libdir}/ocaml/cairo2-pango/cairo_pango.cmti
%{_libdir}/ocaml/cairo2-pango/cairo_pango.mli
%{_libdir}/ocaml/cairo2-pango/dune-package
%{_libdir}/ocaml/cairo2-pango/libcairo_pango_stubs.a
%{_libdir}/ocaml/cairo2-pango/opam



%changelog
* Thu Oct 20 2022 pterjan <pterjan> 2:0.6.4-1.mga9
+ Revision: 1898076
- Update to 0.6.4

* Thu May 19 2022 pterjan <pterjan> 2:0.6.2-3.mga9
+ Revision: 1859005
- Rebuild for OCaml 4.14

* Wed Apr 06 2022 umeabot <umeabot> 2:0.6.2-2.mga9
+ Revision: 1845912
- Mageia 9 Mass Rebuild

* Tue Oct 12 2021 tv <tv> 2:0.6.2-1.mga9
+ Revision: 1750774
- Rebuild for ocaml-4.12
- Avoid a GC-related segfault
- Fix builds of consuming packages with -fno-common

* Wed Mar 03 2021 tv <tv> 2:0.6.1-5.mga9
+ Revision: 1696566
- Rebuild for ocaml-4.12
- Avoid a GC-related segfault
- Fix builds of consuming packages with -fno-common

* Sun Jan 10 2021 pterjan <pterjan> 2:0.6.1-4.mga8
+ Revision: 1670434
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 2:0.6.1-3.mga8
+ Revision: 1551481
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 2:0.6.1-2.mga8
+ Revision: 1544330
- Mageia 8 Mass Rebuild

* Sat Jan 25 2020 tv <tv> 2:0.6.1-1.mga8
+ Revision: 1482872
- New upstream version 0.6.1
- Add -gtk and -pango subpackages corresponding to upstream's opam packages
- Add -gtk-devel and -pango-devel subpackages to manage dependencies
- Add %%check script (disabled for now)

* Sun Jan 19 2020 tv <tv> 2:0.4.7-0.5.gitbe5a298.mga8
+ Revision: 1481548
- new release + rebuild for ocaml-4.10

* Wed Oct 24 2018 pterjan <pterjan> 2:0.4.7-0.4.gitbe5a298.mga7
+ Revision: 1325034
- Rebuild for ocaml 4.07.1

* Wed Oct 03 2018 pterjan <pterjan> 2:0.4.7-0.3.gitbe5a298.mga7
+ Revision: 1316328
- Mageia 7 Mass Rebuild

* Sun Nov 26 2017 tv <tv> 2:0.4.7-0.2.gitbe5a298.mga7
+ Revision: 1179953
- fix deps

* Sun Nov 26 2017 tv <tv> 2:0.4.7-0.1.gitbe5a298.mga7
+ Revision: 1179420
- switch to the other (buildable) cairo ocaml project
- rebuild for new ocaml

* Mon Sep 26 2016 pterjan <pterjan> 1.2.0.2-3.mga6
+ Revision: 1056264
- Rebuild for fix in ocaml

* Tue Feb 16 2016 umeabot <umeabot> 1.2.0.2-2.mga6
+ Revision: 961782
- Mageia 6 Mass Rebuild

* Mon Oct 05 2015 eatdirt <eatdirt> 1.2.0.2-1.mga6
+ Revision: 886272
- Upgrade to latest git HEAD 1.2.0.2

* Wed Oct 15 2014 umeabot <umeabot> 1.2.0.1-13.mga5
+ Revision: 742339
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.0.1-12.mga5
+ Revision: 682997
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.2.0.1-11.mga4
+ Revision: 523299
- Mageia 4 Mass Rebuild

* Sat Apr 06 2013 malo <malo> 1.2.0.1-10.mga3
+ Revision: 408604
- fix requires and buildrequires

* Sat Jan 12 2013 umeabot <umeabot> 1.2.0.1-9.mga3
+ Revision: 361181
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Oct 02 2012 blue_prawn <blue_prawn> 1.2.0.1-8.mga3
+ Revision: 302046
- rebuild for new ocaml 4.00

* Sat Sep 29 2012 blue_prawn <blue_prawn> 1.2.0.1-7.mga3
+ Revision: 300045
- new rpm group for ocaml

* Sun Dec 04 2011 malo <malo> 1.2.0.1-6.mga2
+ Revision: 176184
- adding missing Require ocaml-lablgtk2-devel
- spec clean-up
- adding missing Requires ocaml-lablgtk2

* Sun Nov 06 2011 malo <malo> 1.2.0.1-5.mga2
+ Revision: 164430
- using mkrel for release
- imported package ocaml-cairo

